@@ -3,6 +3,7 @@ use crate::lang::SgLang;
 use crate::utils::DiffStyles;
 use anyhow::Result;
 use ast_grep_config::{RuleConfig, Severity};
+use ast_grep_core::Doc;
 use clap::ValueEnum;
 use codespan_reporting::diagnostic::{self, Diagnostic, Label};
 use codespan_reporting::files::SimpleFile;
@@ -157,11 +158,23 @@ impl ColoredProcessor {
   }
 }
 
+fn sg_label_to_code_span_label(label: ast_grep_config::Label<impl Doc>) -> Label<()> {
+  let ret = match label.style {
+    ast_grep_config::LabelStyle::Primary => Label::primary((), label.range()),
+    ast_grep_config::LabelStyle::Secondary => Label::secondary((), label.range()),
+  };
+  if let Some(message) = label.message {
+    ret.with_message(message)
+  } else {
+    ret
+  }
+}
+
 impl PrintProcessor<Buffer> for ColoredProcessor {
   fn print_rule(
     &self,
     matches: Vec<NodeMatch>,
-    file: SimpleFile<Cow<str>, &String>,
+    file: SimpleFile<Cow<str>, &str>,
     rule: &RuleConfig<SgLang>,
   ) -> Result<Buffer> {
     let config = &self.config;
@@ -175,14 +188,11 @@ impl PrintProcessor<Buffer> for ColoredProcessor {
       Severity::Off => unreachable!("turned-off rule should not have match."),
     };
     for m in matches {
-      let range = m.range();
-      let mut labels = vec![Label::primary((), range)];
-      if let Some(secondary_nodes) = m.get_env().get_labels("secondary") {
-        labels.extend(secondary_nodes.iter().map(|n| {
-          let range = n.range();
-          Label::secondary((), range)
-        }));
-      }
+      let labels = rule
+        .get_labels(&m)
+        .into_iter()
+        .map(sg_label_to_code_span_label)
+        .collect();
       let diagnostic = Diagnostic::new(severity)
         .with_code(&rule.id)
         .with_message(rule.get_message(&m))
