@@ -59,7 +59,10 @@ macro_rules! impl_lang {
           .id_for_node_kind(kind, /*named*/ true)
       }
       fn field_to_id(&self, field: &str) -> Option<u16> {
-        self.get_ts_language().field_id_for_name(field)
+        self
+          .get_ts_language()
+          .field_id_for_name(field)
+          .map(|f| f.get())
       }
       fn build_pattern(&self, builder: &PatternBuilder) -> Result<Pattern, PatternError> {
         builder.build(|src| StrDoc::try_new(src, self.clone()))
@@ -107,7 +110,10 @@ macro_rules! impl_lang_expando {
           .id_for_node_kind(kind, /*named*/ true)
       }
       fn field_to_id(&self, field: &str) -> Option<u16> {
-        self.get_ts_language().field_id_for_name(field)
+        self
+          .get_ts_language()
+          .field_id_for_name(field)
+          .map(|f| f.get())
       }
       fn expando_char(&self) -> char {
         $char
