@@ -1,4 +1,6 @@
 //! Provides utility to convert ast-grep data types to lsp data types
+use ast_grep_config::Label;
+use ast_grep_config::LabelStyle;
 use ast_grep_config::RuleConfig;
 use ast_grep_config::Severity;
 use ast_grep_core::tree_sitter::{LanguageExt, StrDoc};
@@ -58,30 +60,89 @@ pub fn diagnostic_to_code_action(
   Some(action)
 }
 
-fn convert_node_to_range<D: Doc>(node_match: &Node<D>) -> Range {
-  let start = node_match.start_pos();
-  let end = node_match.end_pos();
+fn convert_nodes_to_range<D: Doc>(start_node: &Node<D>, end_node: &Node<D>) -> Range {
+  let start = start_node.start_pos();
+  let end = end_node.end_pos();
   Range {
     start: Position {
       line: start.line() as u32,
-      character: start.column(node_match) as u32,
+      character: start.column(start_node) as u32,
     },
     end: Position {
       line: end.line() as u32,
-      character: end.column(node_match) as u32,
+      character: end.column(end_node) as u32,
     },
   }
 }
 
+fn get_related_info<L: LanguageExt>(
+  uri: &Uri,
+  labels: &[Label<StrDoc<L>>],
+) -> Option<Vec<DiagnosticRelatedInformation>> {
+  labels
+    .iter()
+    .filter_map(|label| {
+      let message = label.message?;
+      let range = convert_nodes_to_range(&label.start_node, &label.end_node);
+      Some(DiagnosticRelatedInformation {
+        location: Location {
+          uri: uri.clone(),
+          range,
+        },
+        message: message.to_string(),
+      })
+    })
+    .collect::<Vec<_>>()
+    .into()
+}
+
+fn get_primary_label<L: LanguageExt>(
+  node_match: &NodeMatch<StrDoc<L>>,
+  labels: &[Label<StrDoc<L>>],
+) -> Range {
+  let Some(label) = labels.iter().find(|l| l.style == LabelStyle::Primary) else {
+    return convert_nodes_to_range(node_match, node_match);
+  };
+  let start = label.start_node.start_pos();
+  let end = label.end_node.end_pos();
+  Range {
+    start: Position {
+      line: start.line() as u32,
+      character: start.column(&label.start_node) as u32,
+    },
+    end: Position {
+      line: end.line() as u32,
+      character: end.column(&label.end_node) as u32,
+    },
+  }
+}
+
+fn get_node_range_and_related_info<L: LanguageExt>(
+  uri: &Uri,
+  node_match: &NodeMatch<StrDoc<L>>,
+  rule: &RuleConfig<L>,
+) -> (Range, Option<Vec<DiagnosticRelatedInformation>>) {
+  // if user has not specified any labels, we don't need to show anything
+  // the default labels are pretty noisy
+  if rule.labels.is_none() {
+    let range = convert_nodes_to_range(node_match, node_match);
+    return (range, None);
+  }
+  let labels = rule.get_labels(node_match);
+  let related_information = get_related_info(uri, &labels);
+  (get_primary_label(node_match, &labels), related_information)
+}
+
 pub fn convert_match_to_diagnostic<L: LanguageExt>(
+  uri: &Uri,
   node_match: NodeMatch<StrDoc<L>>,
   rule: &RuleConfig<L>,
 ) -> Diagnostic {
-  // TODO
   let rewrite_data =
     RewriteData::from_node_match(&node_match, rule).and_then(|r| serde_json::to_value(r).ok());
+  let (range, related_information) = get_node_range_and_related_info(uri, &node_match, rule);
   Diagnostic {
-    range: convert_node_to_range(&node_match),
+    range,
     code: Some(NumberOrString::String(rule.id.clone())),
     code_description: url_to_code_description(&rule.url),
     severity: Some(match rule.severity {
@@ -94,7 +155,7 @@ pub fn convert_match_to_diagnostic<L: LanguageExt>(
     message: get_non_empty_message(rule, &node_match),
     source: Some(String::from("ast-grep")),
     tags: None,
-    related_information: None,
+    related_information,
     data: rewrite_data,
   }
 }
