@@ -86,14 +86,14 @@ impl ContentExt for Wrapper {
     let old_end_position = pos_for_byte_offset(input, old_end_byte);
     input.splice(start_byte / 2..old_end_byte / 2, edit.inserted_text.clone());
     let new_end_position = pos_for_byte_offset(input, new_end_byte);
-    InputEdit::new(
-      start_byte as u32,
-      old_end_byte as u32,
-      new_end_byte as u32,
-      &start_position,
-      &old_end_position,
-      &new_end_position,
-    )
+    InputEdit {
+      start_byte,
+      old_end_byte,
+      new_end_byte,
+      start_position,
+      old_end_position,
+      new_end_position,
+    }
   }
 }
 
@@ -124,10 +124,10 @@ fn parse(
   lang: &NapiLang,
   old_tree: Option<&Tree>,
 ) -> std::result::Result<Tree, TSParseError> {
-  let mut parser = Parser::new()?;
+  let mut parser = Parser::new();
   let ts_lang = lang.get_ts_language();
   parser.set_language(&ts_lang)?;
-  if let Some(tree) = parser.parse_utf16_le(source.inner.as_slice(), old_tree)? {
+  if let Some(tree) = parser.parse_utf16_le(source.inner.as_slice(), old_tree) {
     Ok(tree)
   } else {
     Err(TSParseError::TreeUnavailable)
