@@ -67,7 +67,7 @@ impl_lang_mod!(css, Css);
 /// Parse a string to an ast-grep instance
 #[napi]
 pub fn parse(lang: String, src: String) -> Result<SgRoot> {
-  let doc = JsDoc::new(src, lang.parse()?);
+  let doc = JsDoc::try_new(src, lang.parse()?)?;
   Ok(SgRoot(AstGrep::doc(doc), "anonymous".into()))
 }
 
@@ -86,9 +86,7 @@ pub fn parse_async(lang: String, src: String) -> Result<AsyncTask<ParseAsync>> {
 #[napi]
 pub fn kind(lang: String, kind_name: String) -> Result<u16> {
   let lang: NapiLang = lang.parse()?;
-  let kind = lang
-    .get_ts_language()
-    .id_for_node_kind(&kind_name, /* named */ true);
+  let kind = lang.kind_to_id(&kind_name);
   Ok(kind)
 }
 
